(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     53382,       1348]
NotebookOptionsPosition[     47792,       1252]
NotebookOutlinePosition[     48160,       1268]
CellTagsIndexPosition[     48117,       1265]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "\"\<OperatorGB.m\>\""}]}], "Input",
 CellChangeTimes->{{3.789385558366721*^9, 3.789385576085824*^9}, {
  3.789576982763996*^9, 3.7895770038309107`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"d7f83bb0-081e-4ad3-84a7-7cc933d66735"],

Cell[BoxData["\<\"Package OperatorGB version 1.2.0\\nCopyright 2019, \
Institute for Algebra, JKU\\nby Clemens Hofstadler, clemens.hofstadler@jku.at\
\"\>"], "Print",
 CellChangeTimes->{3.7893855774844093`*^9, 3.78957700608803*^9, 
  3.789577242620778*^9, 3.789577623109762*^9, 3.7895808311342707`*^9, 
  3.7895834475671062`*^9, 3.7895835037333803`*^9, 3.789583653622033*^9, 
  3.789584754607476*^9, 3.7924948283414097`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"d35a845b-d5fe-4c0f-9320-d82594882a7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example file for the paper \[OpenCurlyDoubleQuote]Compatible rewriting of \
noncommutative polynomials for proving operator identities\
\[CloseCurlyDoubleQuote]\
\>", "Section",
 CellChangeTimes->{{3.7895812356599817`*^9, 3.789581245974888*^9}, {
  3.789583742905941*^9, 3.7895837659529257`*^9}, {3.789584395610408*^9, 
  3.789584397223168*^9}},ExpressionUUID->"16b5c6e2-d00a-4745-a104-\
0712f303320a"],

Cell["\<\
The noncommutative polynomials corresponding to the operator identities:\
\>", "Text",
 CellChangeTimes->{{3.789577476897366*^9, 3.789577479272882*^9}, {
  3.789577521869156*^9, 3.7895775340344057`*^9}, {3.789584586499002*^9, 
  3.7895846019484386`*^9}},ExpressionUUID->"f4a1ecbe-1eff-44ae-b84f-\
358fcb31c265"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "1"]}], "-", 
      RowBox[{
       SubscriptBox["h", "1"], "**", "d"}], "-", 
      RowBox[{
       SubscriptBox["b", "1"], "**", 
       SubscriptBox["h", "1"]}]}], ",", 
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["h", "2"], "**", "d"}], "-", 
      RowBox[{
       SubscriptBox["b", "2"], "**", 
       SubscriptBox["h", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", "1"], "**", 
       SubscriptBox[
        OverscriptBox["h", "~"], "1"]}], "-", "1"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", "2"], "**", 
       SubscriptBox[
        OverscriptBox["h", "~"], "2"]}], "-", "1"}], ",", 
     RowBox[{
      RowBox[{"d", "**", "i"}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["b", "1"]}], ")"}], "**", 
     RowBox[{"(", 
      RowBox[{"d", "-", 
       SubscriptBox["b", "2"]}], ")"}], "**", 
     SubscriptBox["h", "2"], "**", "i", "**", 
     SubscriptBox[
      OverscriptBox["h", "~"], "2"], "**", 
     SubscriptBox["h", "1"], "**", "i", "**", 
     SubscriptBox[
      OverscriptBox["h", "~"], "1"]}], "-", "1"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.789577425885141*^9, 3.78957747125984*^9}, {
   3.789578009035201*^9, 3.789578018219987*^9}, 3.789582475171707*^9},
 CellLabel->"In[3]:=",ExpressionUUID->"8869a94c-9aa6-4f2b-9635-dcaba5b46324"],

Cell[TextData[{
 "We typically want to work with fully expanded polynomials (this makes \
equality checking easier) but Mathematica\[CloseCurlyQuote]s noncommutative \
multiplication cannot be expanded. So, we translate the polynomial ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "5c603325-ee85-43c3-a912-e30c746e8f3e"],
 " into our own data structure, where it gets expanded automatically, and \
then translate it back into Mathematica\[CloseCurlyQuote]s noncommutative \
data structure for better readability."
}], "Text",
 CellChangeTimes->{{3.7895780226140137`*^9, 3.789578208928915*^9}, {
  3.7895782455168457`*^9, 
  3.789578271696824*^9}},ExpressionUUID->"cc8e00d0-2181-4bc8-bd77-\
403ac3be4851"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", " ", "=", " ", 
  RowBox[{"ToNonCommutativeMultiply", "[", 
   RowBox[{"ToProd", "[", "f", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.78957821561165*^9, 3.789578224595777*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"c0e65378-0cef-4008-9314-ef72380f9aca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{"d", "**", "d", "**", 
   SubscriptBox["h", "2"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "2"], "**", 
   SubscriptBox["h", "1"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "1"]}], "-", 
  RowBox[{"d", "**", 
   SubscriptBox["b", "2"], "**", 
   SubscriptBox["h", "2"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "2"], "**", 
   SubscriptBox["h", "1"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "1"]}], "-", 
  RowBox[{
   SubscriptBox["b", "1"], "**", "d", "**", 
   SubscriptBox["h", "2"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "2"], "**", 
   SubscriptBox["h", "1"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "1"]}], "+", 
  RowBox[{
   SubscriptBox["b", "1"], "**", 
   SubscriptBox["b", "2"], "**", 
   SubscriptBox["h", "2"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "2"], "**", 
   SubscriptBox["h", "1"], "**", "i", "**", 
   SubscriptBox[
    OverscriptBox["h", "~"], "1"]}]}]], "Output",
 CellChangeTimes->{3.789578225071683*^9, 3.789579047388772*^9, 
  3.7895808357259827`*^9, 3.789582478495364*^9, 3.789583447698044*^9, 
  3.789583507841004*^9, 3.7895836537596483`*^9, 3.789584754709731*^9, 
  3.792494838946624*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"24eb401b-95cc-4f74-b43e-373aca1e4a44"]
}, Open  ]],

Cell["\<\
Defining the quiver capturing the information about domains and codomains of \
the operators involved.\
\>", "Text",
 CellChangeTimes->{{3.7895776384360113`*^9, 
  3.789577673055379*^9}},ExpressionUUID->"f1f2a59c-9062-4f11-8404-\
a7dbddae60e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", 
       SubscriptBox["v", "1"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["h", "2"], ",", 
       SubscriptBox["v", "1"], ",", 
       SubscriptBox["v", "1"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["h", "1"], ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["h", "2"], ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["h", "~"], "2"], ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["h", "1"], ",", 
       SubscriptBox["v", "3"], ",", 
       SubscriptBox["v", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox[
        OverscriptBox["h", "~"], "1"], ",", 
       SubscriptBox["v", "3"], ",", 
       SubscriptBox["v", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["b", "1"], ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["b", "2"], ",", 
       SubscriptBox["v", "1"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       SubscriptBox["v", "3"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "1"]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789385583609282*^9, 3.789385625896449*^9}, {
  3.789385680384942*^9, 3.789385849126432*^9}, {3.789385900530315*^9, 
  3.789385911762065*^9}, {3.7893859740561037`*^9, 3.7893859779980993`*^9}, {
  3.789386021218388*^9, 3.789386022312298*^9}, {3.7895775620098953`*^9, 
  3.7895776155182743`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"fc4f6aab-0ae2-4f5a-ad15-c54c2834fd72"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotQuiver", "[", "Q", "]"}]], "Input",
 CellChangeTimes->{{3.789385828277946*^9, 3.789385854502562*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"fdb6a3a0-57a5-4030-8f60-622cfe25fea8"],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.6, 0.7, 0.5], Opacity[0.7], {InsetBox[
      SubscriptBox["h", 
       "2"], {-0.08844560149659522, -1.1587952819525071*^-17}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQjQEE4lzt7v/ct+1OUcCO3ZH7H1S1zzIPKdrf/joo
Ncl+3n6PrTI88X8m7D+0783db1Zr9rswPy67I7do/73gR3PcOjfv3/Tt5/Xb
aev2V3xkZnuZvH2/i3K21X+dbfvTPxYy2Mft3O/mbSL1Mmfv/v6la5NX++/c
b6uQxaCuf2i/1EHBxkjL7fsVkndF+1ke3e84eYaiqtvm/SyvC9/UTzu+/ynj
p9chfav3H6o3mGogdnL/wSPTHIW2ztk/ayYInNxfdCz4NadtzR6Y/D6IvD1M
/z2IfntFqPl2EPPt7aD2i0Pst4e5rxfiPns3qPtTIe633wr1XznEf/ZuUP/f
hfjf3gcaPgch4WN/ABp+2ZDws4eF7w5I+NqjBz8ATtW/Pg==
       "]]}}, {
     InsetBox["d", {0.5001527564386756, 0.051719035348908725}], 
     {Arrowheads[0.03], 
      ArrowBox[{{0., 0.}, {0.10564643085064196`, 0.03697625079772471}, {
       0.13258131914131138`, 0.04568230929144568}, {0.15990362835957012`, 
       0.053083328188110235`}, {0.18755016697518334`, 0.05916219027754255}, {
       0.21545699357431009`, 0.06390483625771037}, {0.24355956474435997`, 
       0.06730029725133291}, {0.2717928843511636, 0.06934072017489767}, {
       0.3000916538632056, 0.0700213859014146}, {0.7002138590141457, 
       0.0700213859014146}, {0.7285126285261877, 0.06934072017489767}, {
       0.7567459481329913, 0.06730029725133291}, {0.7848485193030412, 
       0.06390483625771037}, {0.8127553459021679, 0.05916219027754244}, {
       0.8404018845177812, 0.053083328188110124`}, {0.8677241937360399, 
       0.045682309291445566`}, {0.8946590820267093, 0.0369762507977246}, {
       1.0003055128773508`, 4.665773677819736*^-18}}]}}, {InsetBox[
      SubscriptBox["b", "2"], {0.5001527564386754, 2.332886838909868*^-18}], 
     {Arrowheads[0.03], 
      ArrowBox[{{0., 0.}, {1.0003055128773508`, 4.665773677819736*^-18}}]}}, {
     InsetBox["i", {0.5001527564386755, -0.051719035348908725}], 
     {Arrowheads[0.03], 
      ArrowBox[{{1.0003055128773508`, 4.665773677819736*^-18}, {
       0.8946590820267091, -0.03697625079772471}, {
       0.8677241937360396, -0.04568230929144568}, {
       0.8404018845177809, -0.053083328188110235`}, {
       0.8127553459021676, -0.05916219027754255}, {
       0.7848485193030409, -0.06390483625771037}, {
       0.756745948132991, -0.06730029725133291}, {
       0.7285126285261874, -0.06934072017489767}, {
       0.7002138590141453, -0.0700213859014146}, {
       0.30009165386320524`, -0.0700213859014146}, {
       0.2717928843511633, -0.06934072017489767}, {
       0.24355956474435966`, -0.06730029725133291}, {
       0.21545699357430975`, -0.06390483625771037}, {
       0.187550166975183, -0.05916219027754244}, {
       0.1599036283595698, -0.053083328188110124`}, {
       0.13258131914131108`, -0.045682309291445566`}, {
       0.10564643085064163`, -0.0369762507977246}, {0., 0.}}]}}, {InsetBox[
      SubscriptBox["h", "1"], {1.1329454244512762, -0.07657968865249402}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAUhF9WkAB8D8MRSCRX4RVPC1cH+5U
EvI/KOdOOubNi7+ga83fTTzyP0TBeeXn84+/YaetbBlk8j9AP0WMiOeTvxt/
ri1riPI/KkaMc+GOmb+0EhTEE6jyPyIMuJdiYKC/wEd5vwrC8j/CJbZcjaCk
vxiMoT531fI/eoQyvW9kqb9QVgkDt+HyPwLe1TY8hK6/raoZvGPm8j+L4fbD
kuqxvwLaxl1W4/I/qefdGWKVtL8497dmqNjyP0yKrrRELLe/lrJSC7PG8j+Y
mZmZmZm5v99fnkwMrvI/kUwA5RrJu7+i+E0Tgo/yPyho0CCHqL2/2eXSdxNs
8j+kazvBOSi/v0Halm/oRPI/bnwK59YdwL8RxuIkSBvyP/J4uTrzbMC/UvMb
So7w8T9xJwoP3X7Av3eigcEfxvE/9iE/w/5SwL8f/i34Xp3xPxeqn4iN1b+/
uzWeVaB38T/UkWswN5O+v2cXWiAfVvE/hRcm7X7pvL+gMYE08znxPw105LdI
5rq/UhF9WkAB8D8MRSCRX4RVPHWo0QY=
       "]]}}, {InsetBox[
      SubscriptBox["h", "2"], {1.0003055128773506, -0.1531593773049881}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQHSRYG+XA+MGex1VhYnxLqM19a2mRRTc/2H8O0Ktn
Tdi3vzv1g2T+8w/2N5a/+vK3+MD+H009hTvffrC/XLBvZc+xg/v9Jv3t93nz
wf5i7MFPi2QO7+9v5I81efzB/r+KbqZ49pH9B1Jvnd9z6YP94w3maQzLj+6P
uG5dkr/7g72QFJsW/7Fj+xN637/lm/fB/sPn/V+e7ju+X+3a4XkTqj/Yz1Kb
6ZTWeWL/pk9fl4iEfrB/pR4+94vcyf2rV0wruaP9wb4g+/qZ9VUn98PcP2sm
CJzc/+nzsQaPte/h8k/jORRuRL2H6/8zI0fnAe97uPntWqJ9j0+8s/8ItX/6
tJpGpb53cPedqLQ/1R7/Du5+baer62fYvYP7b63CT88MnXf2l6D+j7C/3dan
CeRDw8eoSthM2ewdPPw6z+513BsItA8avujhDwD4Uttx
       "]]}}, {InsetBox[
      SubscriptBox[
       OverscriptBox["h", "~"], 
       "2"], {0.8676656013034253, -0.0765796886524941}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAUhF9WkAB8D8MRSCRX4RVPAni8QAb
ke0/EHTkt0jmur96FkApw1jtP4cXJu1+6by/0tm3vsAV7T/WkWswN5O+vwpJ
mHlDyuw/GqqfiI3Vv79aAPHmwXjsP/chP8P+UsC/pV681eQj7D9zJwoP3X7A
vya5LiBxzus/9Hi5OvNswL/GkMaKMHvrP3F8CufWHcC/lnlOetos6z+qazvB
OSi/vwRUWEP95eo/LmjQIIeovb+LhbfQ6KjqP5hMAOUaybu/HOBOU5t36j+e
mZmZmZm5v9hWhJywU+o/UoqutEQst79EkWauVD7qP67n3RlilbS/7u/A8Tk4
6j+T4fbDkuqxv6mY4WOTQeo/Et7VNjyErr8ZLbHsElrqP4iEMr1vZKm/yLUB
6+uA6j/OJbZcjaCkv+EfzOHZtOo/LQy4l2JgoL8SR5cOK/TqPz5GjHPhjpm/
hfaYkM486z9YP0WMiOeTvwhuWapljOs/aMF55efzj7/tjLWNV+DrP0jnTjrm
zYu/UhF9WkAB8D8MRSCRX4RVPB4F1yw=
       "]]}}, {
     InsetBox["d", {1.5001527097553522, 0.051687438510710254}], 
     {Arrowheads[0.03], 
      ArrowBox[{{1.0003055128773508`, 4.665773677819736*^-18}, {
       1.1058874008926651`, 0.03695366080536}, {1.1328058337854048`, 
       0.04565440048522995}, {1.160111450917708, 0.05305089785911277}, {
       1.1877410993650979`, 0.05912604617429207}, {1.2156308767776198`, 
       0.06386579471801979}, {1.24371627917435, 0.06725918131425845}, {
       1.271932350129368, 0.06929835767719927}, {1.3002138310041518`, 
       0.06997860756292018}, {1.7000915885065522`, 0.06997860756292018}, {
       1.728373069381336, 0.06929835767719927}, {1.756589140336354, 
       0.06725918131425845}, {1.7846745427330841`, 0.06386579471801979}, {
       1.812564320145606, 0.05912604617429196}, {1.840193968592996, 
       0.053050897859112656`}, {1.8674995857252994`, 0.04565440048522984}, {
       1.894418018618039, 0.03695366080535989}, {1.9999999066333527`, 
       4.956174529136317*^-18}}]}}, {InsetBox[
      SubscriptBox["b", "1"], {1.5001527097553518, 4.810974103478027*^-18}], 
     {Arrowheads[0.03], 
      ArrowBox[{{1.0003055128773508`, 4.665773677819736*^-18}, {
       1.9999999066333527`, 4.956174529136317*^-18}}]}}, {
     InsetBox["i", {1.500152709755352, -0.051687438510710254}], 
     {Arrowheads[0.03], 
      ArrowBox[{{1.9999999066333527`, 4.956174529136317*^-18}, {
       1.8944180186180386`, -0.03695366080536}, {
       1.867499585725299, -0.04565440048522995}, {
       1.8401939685929958`, -0.05305089785911277}, {
       1.8125643201456056`, -0.05912604617429207}, {
       1.784674542733084, -0.06386579471801979}, {
       1.7565891403363536`, -0.06725918131425845}, {
       1.7283730693813357`, -0.06929835767719927}, {
       1.700091588506552, -0.06997860756292018}, {
       1.3002138310041516`, -0.06997860756292018}, {
       1.2719323501293678`, -0.06929835767719927}, {
       1.2437162791743497`, -0.06725918131425845}, {
       1.2156308767776196`, -0.06386579471801979}, {
       1.1877410993650976`, -0.05912604617429196}, {
       1.1601114509177077`, -0.053050897859112656`}, {
       1.1328058337854043`, -0.04565440048522984}, {
       1.105887400892665, -0.03695366080535989}, {1.0003055128773508`, 
       4.665773677819736*^-18}}]}}, {InsetBox[
      SubscriptBox["h", "1"], {2.035028639009981, 0.10780735296366632}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAkuTv5v///z8P3rTWN9tWPHUflP9K
aP8/LpewETjspj8ZMbghtTj/PzLaIqlpD7A/g6mDBH8b/z/rFlooQjm1P741
Su1AEv8/tGrz13qruj+ORYsJfB3/PwXIvb36DMA/qJKAYZM8/z9ghkkSZJzC
P4PH92nUbf8/J5vwGTHgxD8DFbG9jq7/P5Vw+Ui6uMY/WbOusjn7/z8WGT5C
MwzIP3LfFt/SJwBA0KiXaBPIyD9Qb316m1MAQP7nn+cY4sg/UYs/u5J+AECa
3WkP2FjIP5llFx9gpgBAvCuOL88zxz/LCr1a18gAQIhhCNz9gsU/tnjnuBbk
AEB4LalTBV7DP73W22ah9gBApOw9Pd7iwD81rfk+dP8AQLEPmYZraLw/jeat
7hP+AEBKQf/ZEe+2PxywDrKT8gBAnjLzUzGmsT8PVQZHlN0AQJDtPLBMr6k/
VmW6JjvAAEA+LZ79Po2hP62P1n8inABAUDwjeMqvlj8BaKrRQnMAQEC1N3YT
mI0/kuTv5v///z8P3rTWN9tWPN/Cw8U=
       "]]}}, {InsetBox[
      SubscriptBox[
       OverscriptBox["h", "~"], 
       "1"], {2.035028639009981, -0.10780735296366631}], 
     {Arrowheads[0.03], ArrowBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAkuTv5v///z8P3rTWN9tWPAFoqtFC
cwBAMLU3dhOYjb+tj9Z/IpwAQEQ8I3jKr5a/VmW6JjvAAEA4LZ79Po2hvw9V
BkeU3QBAie08sEyvqb8csA6yk/IAQJsy81MxprG/jeat7hP+AEBGQf/ZEe+2
vzWt+T50/wBArA+ZhmtovL+91ttmofYAQJ/sPT3e4sC/tnjnuBbkAEB2LalT
BV7Dv8sKvVrXyABAiGEI3P2Cxb+ZZRcfYKYAQLorji/PM8e/UYs/u5J+AECY
3WkP2FjIv1BvfXqbUwBA/uef5xjiyL9y3xbf0icAQM6ol2gTyMi/WbOusjn7
/z8WGT5CMwzIvwQVsb2Orv8/l3D5SLq4xr+Dx/dp1G3/Pyeb8Bkx4MS/qJKA
YZM8/z9hhkkSZJzCv45Fiwl8Hf8/BMi9vfoMwL++NUrtQBL/P7Zq89d6q7q/
g6mDBH8b/z/2FlooQjm1vxkxuCG1OP8/N9oiqWkPsL91H5T/Smj/PzCXsBE4
7Ka/kuTv5v///z8P3rTWN9tWPGK9zxo=
       "]]}}}, 
   {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
    DiskBox[{0., 0.}, 0.022611464210583382], 
    DiskBox[{1.0003055128773508, 4.665773677819736*^-18}, 
     0.022611464210583382], 
    DiskBox[{1.9999999066333527, 4.956174529136317*^-18}, 
     0.022611464210583382]}},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImageSize->{879.7421875, Automatic}]], "Output",
 CellChangeTimes->{
  3.7893858553280563`*^9, {3.789385902331789*^9, 3.789385914623506*^9}, 
   3.789385980964734*^9, 3.7895770122652397`*^9, 3.789577245090301*^9, {
   3.789577618299032*^9, 3.789577625275922*^9}, 3.789579051482799*^9, 
   3.789582487292838*^9, 3.7895834478004*^9, 3.7895835102977133`*^9, 
   3.789583653875945*^9, 3.789584754807506*^9, 3.7924948392654247`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"1f918a0d-0115-47df-a6fc-571caf0c1954"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.789386120718307*^9, 3.789386191438422*^9}, 
   3.789577422586368*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"676be07a-7436-40eb-a297-6bb4498d6d77"],

Cell[TextData[{
 "We can check that all polynomials in ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "9158f8cf-75ff-467b-8cad-fd61a5628609"],
 " as well as ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "834f7dd2-2797-469c-b3f4-8c65437f0e68"],
 " are compatible with ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "c2f9de34-c87b-4aff-98d6-45cbf9a7a47e"],
 " by computing their signatures...."
}], "Text",
 CellChangeTimes->{{3.789578983470245*^9, 3.78957902495686*^9}, {
  3.789579076485716*^9, 3.789579101873444*^9}, {3.789579168025118*^9, 
  3.7895791698361692`*^9}},ExpressionUUID->"fb3067f3-d419-439f-9110-\
f14b7ad501ed"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"QSignature", "[", 
    RowBox[{"#", ",", "Q"}], "]"}], "&"}], "/@", "F"}], "\[IndentingNewLine]", 
 RowBox[{"QSignature", "[", 
  RowBox[{"f", ",", "Q"}], "]"}]}], "Input",
 CellChangeTimes->{{3.789579027525126*^9, 3.789579062048745*^9}, {
  3.7895791350732603`*^9, 3.789579152101437*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"10bad424-ce59-4176-b31f-bd7eb4627f77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "2"], ",", 
      SubscriptBox["v", "3"]}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"]}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "3"], ",", 
      SubscriptBox["v", "3"]}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "2"], ",", 
      SubscriptBox["v", "2"]}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["v", "2"], ",", 
       SubscriptBox["v", "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["v", "3"], ",", 
       SubscriptBox["v", "3"]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7895790405240173`*^9, 3.789579062751588*^9}, 
   3.789579152337297*^9, 3.789580840963973*^9, 3.789582489027858*^9, 
   3.789583447854661*^9, 3.7895835121049547`*^9, 3.7895836539291897`*^9, 
   3.789584754851904*^9, 3.792494839349066*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"3f0fe16e-d6a3-4439-b148-3722b4505f90"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["v", "3"], ",", 
    SubscriptBox["v", "3"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.7895790405240173`*^9, 3.789579062751588*^9}, 
   3.789579152337297*^9, 3.789580840963973*^9, 3.789582489027858*^9, 
   3.789583447854661*^9, 3.7895835121049547`*^9, 3.7895836539291897`*^9, 
   3.789584754851904*^9, 3.7924948393537273`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"a054b123-2007-4835-8139-2f4f68564558"]
}, Open  ]],

Cell[TextData[{
 "...or simply by using the function ",
 Cell[BoxData[
  FormBox["CompatibleQ", TraditionalForm]],ExpressionUUID->
  "31c743ab-a1f6-4c58-9482-d32a912c0b47"],
 "."
}], "Text",
 CellChangeTimes->{{3.7895791055972652`*^9, 3.789579132513324*^9}, {
  3.789581279032866*^9, 
  3.789581280707471*^9}},ExpressionUUID->"66f80ff5-b94f-4453-bf7c-\
29c9d3b666be"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CompatibleQ", "[", 
    RowBox[{"#", ",", "Q"}], "]"}], "&"}], "/@", "F"}], "\[IndentingNewLine]", 
 RowBox[{"CompatibleQ", "[", 
  RowBox[{"f", ",", "Q"}], "]"}]}], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"f6ae925a-d829-4caf-82a2-c8a3f681750a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.789579136731873*^9, 3.789580842587208*^9, 
  3.789582490322877*^9, 3.789583447904674*^9, 3.789583513514915*^9, 
  3.78958365394429*^9, 3.789584754863838*^9, 3.792494839370756*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"e9adfec5-def1-44e7-9ad0-387ca239e9ee"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.789579136731873*^9, 3.789580842587208*^9, 
  3.789582490322877*^9, 3.789583447904674*^9, 3.789583513514915*^9, 
  3.78958365394429*^9, 3.789584754863838*^9, 3.792494839373941*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"a22bb3b2-85ce-4c53-9a0a-154b93c540b7"]
}, Open  ]],

Cell["We introduce the following degree-lexicographic ordering....", "Text",
 CellChangeTimes->{{3.789577888420555*^9, 3.789577936339625*^9}, {
  3.789578437626149*^9, 3.789578471969248*^9}, {3.789579329513509*^9, 
  3.789579346828989*^9}, {3.789580952589613*^9, 3.789581099723865*^9}, {
  3.78958113737171*^9, 3.789581182702526*^9}, {3.789581295133029*^9, 
  3.789581384344885*^9}, {3.7895814331564074`*^9, 
  3.789581436776557*^9}},ExpressionUUID->"6c8e7351-8760-4aa6-aa73-\
de4a1539d821"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetUpRing", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["b", "1"], ",", 
    SubscriptBox["b", "2"], ",", 
    SubscriptBox["h", "1"], ",", 
    SubscriptBox["h", "2"], ",", 
    SubscriptBox[
     OverscriptBox["h", "~"], "1"], ",", 
    SubscriptBox[
     OverscriptBox["h", "~"], "2"], ",", "d", ",", "i"}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"2c62ae4d-b625-4392-9ba2-5e5c9c1b5ac0"],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\\"b\\\", \\\"1\\\"]\\) < \
\\!\\(\\*SubscriptBox[\\\"b\\\", \\\"2\\\"]\\) < \
\\!\\(\\*SubscriptBox[\\\"h\\\", \\\"1\\\"]\\) < \
\\!\\(\\*SubscriptBox[\\\"h\\\", \\\"2\\\"]\\) < \
\\!\\(\\*SubscriptBox[OverscriptBox[\\\"h\\\", \\\"~\\\"], \\\"1\\\"]\\) < \
\\!\\(\\*SubscriptBox[OverscriptBox[\\\"h\\\", \\\"~\\\"], \\\"2\\\"]\\) < \
\\!\\(\\*RowBox[{\\\"d\\\"}]\\) < \\!\\(\\*RowBox[{\\\"i\\\"}]\\)\"\>"], \
"Print",
 CellChangeTimes->{3.789580402311*^9, 3.789580845850848*^9, 
  3.789581101421464*^9, 3.789582493386557*^9, 3.789583447914611*^9, 
  3.789583514938031*^9, 3.789583653988495*^9, 3.789584754908326*^9, 
  3.792494839422881*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"86f1b5a1-4c99-4eda-a772-fd0d39b0bd94"]
}, Open  ]],

Cell[TextData[{
 "...and reduce ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "e3c37787-062d-441c-9817-c144ae5654ce"],
 " by ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "b8e7fcf4-d2f2-4731-ae9d-ba4c389fb311"],
 ". Note that, since the reduction relation induced by ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "48583302-e1fd-41d7-b2f1-9a44868f119b"],
 " is not confluent (i.e. since ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "c92ceccf-dae5-4ded-a8c7-96c20dcdb93d"],
 " is not a Gr\[ODoubleDot]bner basis of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "F", ")"}], TraditionalForm]],ExpressionUUID->
  "dcc2b704-8a5d-4f46-aa39-cb3208877aa6"],
 "), the order of reductions matters. Therefore, we have to reorder ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "cb3940a1-f5b7-4739-bb25-0d8d54331b2d"],
 " in order to obtain zero as a normal form. "
}], "Text",
 CellChangeTimes->{{3.789581410843319*^9, 3.78958150926853*^9}, {
  3.789583423347127*^9, 3.789583425660385*^9}, {3.789584668228177*^9, 
  3.789584668731388*^9}},ExpressionUUID->"5dc6e5b1-504b-4b3c-8073-\
4c3564783afd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   OverscriptBox["F", "~"], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"F", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{"F", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", 
     RowBox[{"F", "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", 
     RowBox[{"F", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ReducedForm", "[", 
  RowBox[{"certificate", ",", 
   OverscriptBox["F", "~"], ",", "f"}], 
  "]"}], "\[IndentingNewLine]", "certificate"}], "Input",
 CellChangeTimes->{{3.78958040386769*^9, 3.789580443670433*^9}, {
  3.789580890822228*^9, 3.789580926954962*^9}, {3.789581764533661*^9, 
  3.7895817655097113`*^9}, {3.789582564619237*^9, 3.789582564830076*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"90cba50f-15db-498c-a3c6-bc45b666a67a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7895804447117147`*^9, 3.78958086815309*^9, {3.7895809130854597`*^9, 
   3.789580927563816*^9}, 3.789580980796318*^9, 3.789581102369416*^9, 
   3.7895815117530203`*^9, 3.78958176584372*^9, 3.789582505651801*^9, 
   3.789583447962186*^9, 3.7895835165803633`*^9, 3.789583654001565*^9, 
   3.789584754947163*^9, 3.7924948394453793`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"35a51da0-73d7-41be-a360-ae8037bff0f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"d", ",", 
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["b", "2"], "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["h", "2"], "**", "d"}]}], ",", 
     RowBox[{"i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["b", "1"]}], ",", 
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["b", "2"], "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["h", "2"], "**", "d"}]}], ",", 
     RowBox[{"i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "**", 
      SubscriptBox["h", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"d", "**", "i"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["b", "1"], "**", 
       SubscriptBox["h", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"d", "**", "i"}]}], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubscriptBox["h", "2"], "**", 
       SubscriptBox[
        OverscriptBox["h", "~"], "2"]}]}], ",", 
     RowBox[{
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["b", "1"]}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubscriptBox["h", "2"], "**", 
       SubscriptBox[
        OverscriptBox["h", "~"], "2"]}]}], ",", 
     RowBox[{
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "1"]}], "-", 
      RowBox[{
       SubscriptBox["b", "1"], "**", 
       SubscriptBox["h", "1"]}], "-", 
      RowBox[{
       SubscriptBox["h", "1"], "**", "d"}]}], ",", 
     RowBox[{"i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["h", "1"], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"d", "**", "i"}]}], ",", 
     SubscriptBox[
      OverscriptBox["h", "~"], "1"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{
       SubscriptBox["h", "1"], "**", 
       SubscriptBox[
        OverscriptBox["h", "~"], "1"]}]}], ",", "1"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7895804447117147`*^9, 3.78958086815309*^9, {3.7895809130854597`*^9, 
   3.789580927563816*^9}, 3.789580980796318*^9, 3.789581102369416*^9, 
   3.7895815117530203`*^9, 3.78958176584372*^9, 3.789582505651801*^9, 
   3.789583447962186*^9, 3.7895835165803633`*^9, 3.789583654001565*^9, 
   3.789584754947163*^9, 3.792494839449437*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"c8cdb166-fc5f-45d1-bf6b-794969c26316"]
}, Open  ]],

Cell["\<\
To see that the obtained certificate corresponds to the decomposition \
presented in Example 3, we do some pretty printing.  \
\>", "Text",
 CellChangeTimes->{{3.7895811172357616`*^9, 3.789581123057392*^9}, {
   3.789581514636292*^9, 3.7895816270457907`*^9}, {3.789581770326974*^9, 
   3.789581816308682*^9}, {3.789581860971087*^9, 3.789581930744701*^9}, 
   3.7895819720797567`*^9, {3.789582438957972*^9, 
   3.789582439812624*^9}},ExpressionUUID->"7d90b94c-1467-4f01-8e10-\
43a708790b91"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"certificate", "//", "CollectLeft"}], ")"}], "/.", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", 
       RowBox[{"F", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", "b_"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       SubscriptBox["\"\<f\>\"", "j"], ",", "b"}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789580445799037*^9, 3.789580552536447*^9}, {
  3.789580586882069*^9, 3.789580606670951*^9}, {3.789580746423963*^9, 
  3.789580748970469*^9}, {3.789580788101746*^9, 3.7895807890485573`*^9}, {
  3.789580861768837*^9, 3.789580864020163*^9}, {3.789581949306078*^9, 
  3.7895819655857563`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"434ba0f7-44a6-4582-aeb7-0e3e1b81deaa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "-", 
      SubscriptBox["b", "1"]}], ",", 
     SubscriptBox["\<\"f\"\>", "2"], ",", 
     RowBox[{"i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "**", 
       SubscriptBox["h", "2"]}], "-", 
      RowBox[{
       SubscriptBox["b", "1"], "**", 
       SubscriptBox["h", "2"]}]}], ",", 
     SubscriptBox["\<\"f\"\>", "5"], ",", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["h", "~"], "2"], "**", 
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "-", 
      SubscriptBox["b", "1"]}], ",", 
     SubscriptBox["\<\"f\"\>", "4"], ",", 
     RowBox[{
      SubscriptBox["h", "1"], "**", "i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SubscriptBox["\<\"f\"\>", "1"], ",", 
     RowBox[{"i", "**", 
      SubscriptBox[
       OverscriptBox["h", "~"], "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["h", "1"], ",", 
     SubscriptBox["\<\"f\"\>", "5"], ",", 
     SubscriptBox[
      OverscriptBox["h", "~"], "1"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SubscriptBox["\<\"f\"\>", "3"], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.789580483661523*^9, 3.789580511149809*^9}, 
   3.789580553252549*^9, {3.789580584747315*^9, 3.789580606910891*^9}, {
   3.789580749533031*^9, 3.7895808121921263`*^9}, {3.789580864457439*^9, 
   3.789580870094685*^9}, 3.789580929605122*^9, {3.7895819534305687`*^9, 
   3.78958197407979*^9}, 3.789582620605962*^9, 3.7895834479761667`*^9, 
   3.7895835228338842`*^9, 3.7895836540491667`*^9, 3.78958475495953*^9, 
   3.79249483950703*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"7367daf1-e64b-4969-a346-3226c27abcdb"]
}, Open  ]],

Cell[TextData[{
 "We can also check that this decomposition is indeed equal to ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "bf181111-632c-4cf6-a287-e16a02f9076d"],
 " when multiplied out."
}], "Text",
 CellChangeTimes->{{3.789581995593925*^9, 
  3.7895820465765944`*^9}},ExpressionUUID->"1f4f95b2-cab9-4001-96b5-\
3bbb746574a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MultiplyOut", "[", "certificate", "]"}], " ", "===", 
  "f"}]], "Input",
 CellChangeTimes->{{3.789577945774022*^9, 3.789577955105474*^9}, {
  3.789578409439404*^9, 3.789578409868375*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"db37a77c-edce-4b90-abc0-2f023060b772"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7895779531843443`*^9, 3.7895779664240513`*^9}, {
   3.789578333436599*^9, 3.78957833586036*^9}, {3.7895784069489403`*^9, 
   3.789578429525515*^9}, 3.789579225413417*^9, 3.7895794109113607`*^9, 
   3.789582624947139*^9, {3.78958344802831*^9, 3.789583466149922*^9}, 
   3.789583524328607*^9, 3.789583654061761*^9, 3.789584754998384*^9, 
   3.792494839526751*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"a15878cf-6348-451a-9772-973c1ab987ae"]
}, Open  ]],

Cell[TextData[{
 "Furthermore, we can now verify that ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "7c6e7291-0d27-4e1e-8ebd-3ebeea82b3ad"],
 " is a ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "26e28e79-58c0-492f-a413-3dcf9e1b0aa1"],
 "-consequence of ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "8fe99305-f6ab-41e8-81f8-11b87a284e2d"],
 " using the definition of ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "63586863-2f3d-410e-9677-7c2030c3410c"],
 "-consequence (implemented by the method QConsequenceQ) or using Proposition \
1 (implemented by QConsequenceQCrit)."
}], "Text",
 CellChangeTimes->{{3.78957847638691*^9, 3.789578495600615*^9}, {
  3.789579303640044*^9, 3.7895793215939074`*^9}, {3.7895793542516623`*^9, 
  3.789579400975519*^9}, {3.789582056931731*^9, 3.789582076020389*^9}, {
  3.789582632470222*^9, 
  3.789582646454545*^9}},ExpressionUUID->"70935010-7dbe-4ad1-9406-\
287e315424ac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"QConsequenceQ", "[", 
  RowBox[{"certificate", ",", "F", ",", "Q"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"QConsequenceQCrit", "[", 
  RowBox[{"certificate", ",", "F", ",", "Q"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7895778574740334`*^9, 3.78957786425401*^9}, {
  3.7895794032176447`*^9, 3.789579406380004*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"31047489-afe3-4d79-80b1-a662bcd36e16"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.78957786474395*^9, 3.789577883662916*^9}, {
   3.789578414062458*^9, 3.789578430297152*^9}, 3.789579226538205*^9, {
   3.7895794067749767`*^9, 3.78957941235079*^9}, 3.789582079656807*^9, {
   3.789582644258853*^9, 3.7895826478387747`*^9}, {3.789583448083284*^9, 
   3.7895834924548397`*^9}, 3.789583526905965*^9, 3.789583654152576*^9, 
   3.789584755040927*^9, 3.79249483959142*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"6761f599-7231-4cbe-bfad-08ba0484f2b2"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.78957786474395*^9, 3.789577883662916*^9}, {
   3.789578414062458*^9, 3.789578430297152*^9}, 3.789579226538205*^9, {
   3.7895794067749767`*^9, 3.78957941235079*^9}, 3.789582079656807*^9, {
   3.789582644258853*^9, 3.7895826478387747`*^9}, {3.789583448083284*^9, 
   3.7895834924548397`*^9}, 3.789583526905965*^9, 3.789583654152576*^9, 
   3.789584755040927*^9, 3.7924948396068373`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"ed3ea968-17df-4be2-8664-7e4e254c78ff"]
}, Open  ]],

Cell[TextData[{
 "Another way of showing that ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "cf6d5b11-9048-4f2e-89dd-f82069a8c407"],
 " is a ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "3758033c-b512-4a05-a88d-f7a7045bf251"],
 "-consequence of ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1e5aa7e5-79e8-4cea-813c-e050863f9d12"],
 ", without having to look into a decomposition of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "20edf51d-247a-4646-aa89-8541be999062"],
 " in terms of ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "31b2e7b4-ca10-41aa-a843-c82f7fb07d75"],
 ", is to use Theorem 3. However, with the monomial ordering defined above \
not all polynomials in ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "994d9de3-9a7e-419f-9931-50a2dd78c88f"],
 " are ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "16f62260-628d-4c3a-99d2-8d4befbd5642"],
 "-order compatible."
}], "Text",
 CellChangeTimes->{{3.78957965612565*^9, 3.7895797070630836`*^9}, {
  3.789579760632416*^9, 3.789579765222191*^9}, {3.789579799628572*^9, 
  3.789579829682537*^9}, {3.789582097164941*^9, 3.78958210185124*^9}, {
  3.789582876057727*^9, 3.78958289421389*^9}, {3.789583096367145*^9, 
  3.789583122086034*^9}, {3.789583158986351*^9, 3.7895832089386263`*^9}, {
  3.7895832553687773`*^9, 
  3.789583295355781*^9}},ExpressionUUID->"9e42ea91-65b0-4d61-8fbb-\
8f2fa24dfb79"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QOrderCompatibleQ", "[", 
    RowBox[{"#", ",", "Q"}], "]"}], "&"}], "/@", "F"}]], "Input",
 CellChangeTimes->{{3.789579709709643*^9, 3.7895797147124166`*^9}, {
  3.789579836087603*^9, 3.789579847314295*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"f0183bc6-1994-420a-8be9-c82fcef5c016"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "False", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.789579715482462*^9, 3.789579847739029*^9, 
  3.7895821031139297`*^9, 3.7895826787846737`*^9, 3.789583448181856*^9, 
  3.7895835465555964`*^9, 3.78958365423991*^9, 3.789584755120508*^9, 
  3.792494839657061*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"4407bb20-2e02-4544-9356-f6a62e15084e"]
}, Open  ]],

Cell[TextData[{
 "But when we change the monomial ordering as done in Example 6, all \
polynomials in ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "a25ecb18-681e-4d34-aef8-d1e4a7643aab"],
 " are ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "4e337391-b4f3-461b-a189-75d0b417d817"],
 "-order compatible. Then, we can apply one iteration of ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],ExpressionUUID->
  "d7980e7b-dcff-4e0c-899a-d1ec7cb29738"],
 "-completion and reduce ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "a9f8bc00-4517-444c-a7f2-6e00d4dbdcd5"],
 " to zero by the obtained partial Gr\[ODoubleDot]bner basis, which also \
proves that ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "8009d316-59e3-46dd-aec2-31e8d7e019a8"],
 " is a ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "553317fb-6e18-4945-a818-ec895eb42a9f"],
 "-consequence of ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "2d2940a3-a6c8-4409-9f81-e5c343ee2a31"],
 "."
}], "Text",
 CellChangeTimes->{{3.7895821899870443`*^9, 3.789582191145513*^9}, {
  3.789582338239326*^9, 3.789582417703404*^9}, {3.789583304442532*^9, 
  3.7895833463013353`*^9}, {3.789583554264264*^9, 
  3.789583557014044*^9}},ExpressionUUID->"220a20c6-2b47-42fc-a94a-\
051bdef2965b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetUpRing", "[", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["b", "1"], ",", 
    SubscriptBox["h", "1"], ",", "d", ",", 
    SubscriptBox["b", "2"], ",", 
    SubscriptBox["h", "2"], ",", 
    SubscriptBox[
     OverscriptBox["h", "~"], "1"], ",", 
    SubscriptBox[
     OverscriptBox["h", "~"], "2"], ",", "i"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.789582201833105*^9, 3.789582240223875*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"b0c9ab05-a8cf-4dcc-9179-b0efd8eadfe0"],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\\"b\\\", \\\"1\\\"]\\) < \
\\!\\(\\*SubscriptBox[\\\"h\\\", \\\"1\\\"]\\) < \\!\\(\\*RowBox[{\\\"d\\\"}]\
\\) < \\!\\(\\*SubscriptBox[\\\"b\\\", \\\"2\\\"]\\) < \\!\\(\\*SubscriptBox[\
\\\"h\\\", \\\"2\\\"]\\) < \\!\\(\\*SubscriptBox[OverscriptBox[\\\"h\\\", \
\\\"~\\\"], \\\"1\\\"]\\) < \\!\\(\\*SubscriptBox[OverscriptBox[\\\"h\\\", \\\
\"~\\\"], \\\"2\\\"]\\) < \\!\\(\\*RowBox[{\\\"i\\\"}]\\)\"\>"], "Print",
 CellChangeTimes->{3.789582203852952*^9, 3.7895822418303537`*^9, 
  3.7895826911931677`*^9, 3.789583365828958*^9, 3.789583448191339*^9, 
  3.789583568401856*^9, 3.7895836542499866`*^9, 3.789584755129409*^9, 
  3.792494839676639*^9},
 CellLabel->
  "During evaluation of \
In[22]:=",ExpressionUUID->"c7316a09-b1f9-4134-8dc1-27e5c7a9e07c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QOrderCompatibleQ", "[", 
    RowBox[{"#", ",", "Q"}], "]"}], "&"}], "/@", "F"}]], "Input",
 CellLabel->"In[23]:=",ExpressionUUID->"73986cf1-efc7-430b-9221-3d4d55729df7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7895822089706373`*^9, 3.789582242925102*^9, 
  3.789582692265108*^9, 3.78958336651547*^9, 3.789583448241481*^9, 
  3.7895835693381853`*^9, 3.7895836542938843`*^9, 3.789584755168065*^9, 
  3.792494839740301*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"0f72f74d-953f-4f74-bf40-b3f9ac502459"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G", " ", "=", " ", 
  RowBox[{"QCompletion", "[", 
   RowBox[{"cofactors", ",", "F", ",", "Q", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.78958224630157*^9, 3.789582295809606*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"0615e4a6-52c8-4ba9-a7cb-1315a05ed6a8"],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.789583367205207*^9, 3.7895834487167873`*^9, 
  3.789583570301326*^9, 3.7895836547920923`*^9, 3.789584755176559*^9, 
  3.7924948397624817`*^9},
 CellLabel->
  "During evaluation of \
In[24]:=",ExpressionUUID->"1ade8603-25f2-4b19-98b4-7ca0fad3672b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "**", 
     SubscriptBox["h", "1"]}], "-", 
    RowBox[{
     SubscriptBox["b", "1"], "**", 
     SubscriptBox["h", "1"]}], "-", 
    RowBox[{
     SubscriptBox["h", "1"], "**", "d"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"d", "**", 
      SubscriptBox["h", "2"]}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], "**", 
     SubscriptBox["h", "2"]}], "+", 
    RowBox[{
     SubscriptBox["h", "2"], "**", "d"}]}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{
     SubscriptBox["h", "1"], "**", 
     SubscriptBox[
      OverscriptBox["h", "~"], "1"]}]}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{
     SubscriptBox["h", "2"], "**", 
     SubscriptBox[
      OverscriptBox["h", "~"], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"d", "**", "i"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"d", "**", 
      SubscriptBox["h", "2"], "**", "i"}]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], "**", 
     SubscriptBox["h", "2"], "**", "i"}], "+", 
    SubscriptBox["h", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.789582280872779*^9, 3.7895822993371983`*^9}, 
   3.789582693435917*^9, 3.789583367415431*^9, 3.7895834512491703`*^9, 
   3.7895835726106863`*^9, 3.7895836573439417`*^9, 3.7895847580207367`*^9, 
   3.792494843141841*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"3f5dd2a7-8fbd-4491-95d8-84beeec88808"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReducedForm", "[", 
  RowBox[{"certificate2", ",", "G", ",", "f"}], "]"}]], "Input",
 CellChangeTimes->{{3.789578678257407*^9, 3.789578776073222*^9}, {
   3.789580262869338*^9, 3.789580294715708*^9}, 3.789582303126689*^9, 
   3.789584739737555*^9},
 CellLabel->"In[25]:=",ExpressionUUID->"d0ed3d84-1018-42b1-99e3-40a5fdbeaa7d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7895787026001997`*^9, {3.7895787370493383`*^9, 3.7895787763646803`*^9}, 
   3.789579232024658*^9, {3.7895802751354218`*^9, 3.789580303440873*^9}, 
   3.789582305765072*^9, 3.7895826949826527`*^9, 3.789583368976041*^9, 
   3.78958345146484*^9, 3.7895835736028013`*^9, 3.7895836575916367`*^9, 
   3.789584758180118*^9, 3.7924948433512907`*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"0d182813-efa9-47bb-a2d3-d261c056c9c0"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1575, 649},
WindowMargins->{{Automatic, -37}, {1, Automatic}},
Magnification:>1.5 Inherited,
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 388, 8, 78, "Input",ExpressionUUID->"d7f83bb0-081e-4ad3-84a7-7cc933d66735"],
Cell[971, 32, 528, 9, 95, "Print",ExpressionUUID->"d35a845b-d5fe-4c0f-9320-d82594882a7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1536, 46, 412, 8, 158, "Section",ExpressionUUID->"16b5c6e2-d00a-4745-a104-0712f303320a"],
Cell[1951, 56, 321, 6, 53, "Text",ExpressionUUID->"f4a1ecbe-1eff-44ae-b84f-358fcb31c265"],
Cell[2275, 64, 1658, 52, 90, "Input",ExpressionUUID->"8869a94c-9aa6-4f2b-9635-dcaba5b46324"],
Cell[3936, 118, 728, 14, 123, "Text",ExpressionUUID->"cc8e00d0-2181-4bc8-bd77-403ac3be4851"],
Cell[CellGroupData[{
Cell[4689, 136, 287, 5, 46, "Input",ExpressionUUID->"c0e65378-0cef-4008-9314-ef72380f9aca"],
Cell[4979, 143, 1427, 39, 84, "Output",ExpressionUUID->"24eb401b-95cc-4f74-b43e-373aca1e4a44"]
}, Open  ]],
Cell[6421, 185, 254, 6, 53, "Text",ExpressionUUID->"f1f2a59c-9062-4f11-8404-a7dbddae60e3"],
Cell[6678, 193, 2288, 68, 98, "Input",ExpressionUUID->"fc4f6aab-0ae2-4f5a-ad15-c54c2834fd72"],
Cell[CellGroupData[{
Cell[8991, 265, 207, 3, 46, "Input",ExpressionUUID->"fdb6a3a0-57a5-4030-8f60-622cfe25fea8"],
Cell[9201, 270, 9570, 171, 292, "Output",ExpressionUUID->"1f918a0d-0115-47df-a6fc-571caf0c1954"]
}, Open  ]],
Cell[18786, 444, 196, 3, 46, "Input",ExpressionUUID->"676be07a-7436-40eb-a297-6bb4498d6d77"],
Cell[18985, 449, 696, 18, 54, "Text",ExpressionUUID->"fb3067f3-d419-439f-9110-f14b7ad501ed"],
Cell[CellGroupData[{
Cell[19706, 471, 415, 9, 78, "Input",ExpressionUUID->"10bad424-ce59-4176-b31f-bd7eb4627f77"],
Cell[20124, 482, 1212, 37, 52, "Output",ExpressionUUID->"3f0fe16e-d6a3-4439-b148-3722b4505f90"],
Cell[21339, 521, 486, 10, 52, "Output",ExpressionUUID->"a054b123-2007-4835-8139-2f4f68564558"]
}, Open  ]],
Cell[21840, 534, 367, 10, 54, "Text",ExpressionUUID->"66f80ff5-b94f-4453-bf7c-29c9d3b666be"],
Cell[CellGroupData[{
Cell[22232, 548, 301, 7, 78, "Input",ExpressionUUID->"f6ae925a-d829-4caf-82a2-c8a3f681750a"],
Cell[22536, 557, 401, 7, 52, "Output",ExpressionUUID->"e9adfec5-def1-44e7-9ad0-387ca239e9ee"],
Cell[22940, 566, 311, 4, 52, "Output",ExpressionUUID->"a22bb3b2-85ce-4c53-9a0a-154b93c540b7"]
}, Open  ]],
Cell[23266, 573, 491, 7, 53, "Text",ExpressionUUID->"6c8e7351-8760-4aa6-aa73-de4a1539d821"],
Cell[CellGroupData[{
Cell[23782, 584, 447, 13, 56, "Input",ExpressionUUID->"2c62ae4d-b625-4392-9ba2-5e5c9c1b5ac0"],
Cell[24232, 599, 788, 14, 36, "Print",ExpressionUUID->"86f1b5a1-4c99-4eda-a772-fd0d39b0bd94"]
}, Open  ]],
Cell[25035, 616, 1202, 31, 90, "Text",ExpressionUUID->"5dc6e5b1-504b-4b3c-8073-4c3564783afd"],
Cell[CellGroupData[{
Cell[26262, 651, 925, 23, 115, "Input",ExpressionUUID->"90cba50f-15db-498c-a3c6-bc45b666a67a"],
Cell[27190, 676, 464, 7, 52, "Output",ExpressionUUID->"35a51da0-73d7-41be-a360-ae8037bff0f1"],
Cell[27657, 685, 3898, 127, 125, "Output",ExpressionUUID->"c8cdb166-fc5f-45d1-bf6b-794969c26316"]
}, Open  ]],
Cell[31570, 815, 500, 9, 53, "Text",ExpressionUUID->"7d90b94c-1467-4f01-8e10-43a708790b91"],
Cell[CellGroupData[{
Cell[32095, 828, 872, 21, 49, "Input",ExpressionUUID->"434ba0f7-44a6-4582-aeb7-0e3e1b81deaa"],
Cell[32970, 851, 2121, 60, 90, "Output",ExpressionUUID->"7367daf1-e64b-4969-a346-3226c27abcdb"]
}, Open  ]],
Cell[35106, 914, 354, 9, 54, "Text",ExpressionUUID->"1f4f95b2-cab9-4001-96b5-3bbb746574a1"],
Cell[CellGroupData[{
Cell[35485, 927, 301, 6, 46, "Input",ExpressionUUID->"db37a77c-edce-4b90-abc0-2f023060b772"],
Cell[35789, 935, 494, 7, 52, "Output",ExpressionUUID->"a15878cf-6348-451a-9772-973c1ab987ae"]
}, Open  ]],
Cell[36298, 945, 1003, 25, 89, "Text",ExpressionUUID->"70935010-7dbe-4ad1-9406-287e315424ac"],
Cell[CellGroupData[{
Cell[37326, 974, 422, 7, 78, "Input",ExpressionUUID->"31047489-afe3-4d79-80b1-a662bcd36e16"],
Cell[37751, 983, 515, 7, 52, "Output",ExpressionUUID->"6761f599-7231-4cbe-bfad-08ba0484f2b2"],
Cell[38269, 992, 518, 7, 52, "Output",ExpressionUUID->"ed3ea968-17df-4be2-8664-7e4e254c78ff"]
}, Open  ]],
Cell[38802, 1002, 1686, 44, 90, "Text",ExpressionUUID->"9e42ea91-65b0-4d61-8fbb-8f2fa24dfb79"],
Cell[CellGroupData[{
Cell[40513, 1050, 334, 7, 46, "Input",ExpressionUUID->"f0183bc6-1994-420a-8be9-c82fcef5c016"],
Cell[40850, 1059, 433, 8, 52, "Output",ExpressionUUID->"4407bb20-2e02-4544-9356-f6a62e15084e"]
}, Open  ]],
Cell[41298, 1070, 1470, 40, 90, "Text",ExpressionUUID->"220a20c6-2b47-42fc-a94a-051bdef2965b"],
Cell[CellGroupData[{
Cell[42793, 1114, 510, 13, 56, "Input",ExpressionUUID->"b0c9ab05-a8cf-4dcc-9179-b0efd8eadfe0"],
Cell[43306, 1129, 793, 12, 36, "Print",ExpressionUUID->"c7316a09-b1f9-4134-8dc1-27e5c7a9e07c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44136, 1146, 217, 5, 46, "Input",ExpressionUUID->"73986cf1-efc7-430b-9221-3d4d55729df7"],
Cell[44356, 1153, 432, 8, 52, "Output",ExpressionUUID->"0f72f74d-953f-4f74-bf40-b3f9ac502459"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44825, 1166, 293, 5, 46, "Input",ExpressionUUID->"0615e4a6-52c8-4ba9-a7cb-1315a05ed6a8"],
Cell[45121, 1173, 303, 6, 36, "Print",ExpressionUUID->"1ade8603-25f2-4b19-98b4-7ca0fad3672b"],
Cell[45427, 1181, 1473, 47, 55, "Output",ExpressionUUID->"3f5dd2a7-8fbd-4491-95d8-84beeec88808"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46937, 1233, 351, 6, 46, "Input",ExpressionUUID->"d0ed3d84-1018-42b1-99e3-40a5fdbeaa7d"],
Cell[47291, 1241, 473, 7, 52, "Output",ExpressionUUID->"0d182813-efa9-47bb-a2d3-d261c056c9c0"]
}, Open  ]]
}, Open  ]]
}
]
*)

